@@ -100,8 +100,9 @@ class MessageBus(object):
                     if target:
                         self.subscribers[topic].remove(target)
                     else:
-                        raise ValueError("No such subscriber found")
+                        pass
             except:
+                print(traceback.format_exception())
                 pass
             #There is a very slight chance someone will
             #Add something to topic before we delete it but after the test.
@@ -162,6 +163,14 @@ class MessageBus(object):
         args = len(inspect.signature(f).parameters)
 
 
+        timestamp = time.monotonic()
+
+        try:
+            desc=str(f.__name__+' of '+f.__module__)
+        except:
+            desc = str(f)
+
+
         #Allright, here is how this works.
         #We have to deal with the possibility that, at any time,
         #The callback will cease to exist. That, in fact, is how one unsubscribes.
@@ -170,6 +179,9 @@ class MessageBus(object):
         #Then we get rid of the empty weakref and if that causes the entire topic
         #To have no subscribers, delete that too in case of memory leak.
         def delsubscription(weakrefobject):
+            if time.monotonic()<timestamp-0.5:
+                logging.warning("Function: " +desc+" was deleted 0.5s after being subscribed.  This is probably not what you wanted.")
+                
             try:
                 with _subscribers_list_modify_lock:
                     self.subscribers[topic].remove(weakrefobject)
@@ -225,7 +237,7 @@ class MessageBus(object):
                     try:
                         if errors:
                             if not alreadyLogged[0]:
-                                handleError(f,topic,message)
+                                handleError(f2,topic,message)
                             alreadyLogged[0]=True
 
                     except Exception as e:
@@ -240,7 +252,7 @@ class MessageBus(object):
                     try:
                         if errors:
                             if not alreadyLogged[0]:
-                                handleError(f,topic,message)
+                                handleError(f2,topic,message)
                             alreadyLogged[0]=True
 
                     except Exception as e:
@@ -255,7 +267,7 @@ class MessageBus(object):
                     try:
                         if errors:
                             if not alreadyLogged[0]:
-                                handleError(f,topic,message)
+                                handleError(f2,topic,message)
                             alreadyLogged[0]=True
                     except Exception as e:
                             print("err",e)
