@@ -10,8 +10,9 @@ class TestAudio(unittest.TestCase):
             
 
     def test_fluidsynth_nojack(self):
-        fs = fluidsynth.FluidSynth()
-        print("Testing fluidsynth without JACK")
+        fs = fluidsynth.FluidSynth(jackClientName="Foo")
+        time.sleep(3)
+        print("Testing fluidsynth with JACK")
         print("You should hear a MIDI note. This test require's fluidsynth, pyFluidsynth, and it's default sf2 file")
         fs.noteOn(0,70,50)
         time.sleep(0.5)
@@ -19,6 +20,7 @@ class TestAudio(unittest.TestCase):
         fs.setInstrument(0,"flute")
         print("You should hear a flute note")
         fs.noteOn(0,70,70)
-        time.sleep(1)
+        time.sleep(2)
         fs.noteOff(0,70)
 
+
